"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pollForEvents = void 0;
const log_1 = require("./log");
const endpoints_1 = require("./endpoints");
const runtime_1 = require("./runtime");
const pollForEvents = async (runtimeApi, bin, endpoint, wsProxy) => {
    (0, log_1.log)("Waiting for next event from Lambda Runtime API", { runtimeApi });
    const { requestId, event, deadline } = await (0, runtime_1.getRuntimeEvent)(runtimeApi);
    let payload = undefined;
    if (bin && !endpoint) {
        (0, log_1.log)("Executing bin", { bin });
        const request = {
            requestId,
            bin,
            event,
            deadline,
        };
        payload = (await (0, endpoints_1.endpointExec)(request)).payload;
        (0, log_1.log)("Bin execution complete");
    }
    else if (endpoint) {
        (0, log_1.log)("Proxying request", { endpoint });
        const request = {
            requestId,
            endpoint,
            event,
            deadline,
            wsProxy,
        };
        payload = (await (0, endpoints_1.endpointProxy)(request)).payload;
        (0, log_1.log)("Proxy request complete");
    }
    else {
        throw new Error(`
Missing bin and handler on _HANDLER: ${process.env._HANDLER}. 
Expected format: {bin}@{endpoint} or {bin} or {endpoint}:
 - next@http://localhost:3000
 - /usr/bin/app@http://localhost:3000
 - http://localhost:3000
 - /usr/bin/app
`);
    }
    await (0, runtime_1.postRuntimeEventResponse)(runtimeApi, requestId, payload);
    (0, log_1.log)("Response sent to Lambda Runtime API", { runtimeApi, requestId });
    return (0, exports.pollForEvents)(runtimeApi, bin, endpoint, wsProxy);
};
exports.pollForEvents = pollForEvents;
