"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebsocketProxy = void 0;
const ws_1 = __importDefault(require("ws"));
const log_1 = require("./log");
function wsify(url) {
    if (!url)
        return undefined;
    if (typeof url === "string")
        url = new URL(url);
    const wsUrl = new URL(url.toString());
    wsUrl.protocol = url.protocol.replace("http", "ws");
    if (!wsUrl.protocol.startsWith("ws")) {
        return undefined;
    }
    return wsUrl;
}
class WebsocketProxy {
    route;
    ws;
    url;
    constructor(url, route) {
        this.route = route;
        this.url = wsify(url);
    }
    init() {
        const { url, route, ws } = this;
        if (!url || !route || ws) {
            (0, log_1.log)("Skipping Websocket Initialization", {
                url,
                route,
                initialized: !!ws,
            });
            return;
        }
        this.ws = new ws_1.default(url);
        this.ws.on("open", this.handleOpen.bind(this));
        this.ws.on("message", this.handleMessage.bind(this));
        this.ws.on("error", this.handleError.bind(this));
        this.ws.on("ping", this.handlePing.bind(this));
        this.ws.on("pong", this.handlePong.bind(this));
    }
    send(data) {
        (0, log_1.log)("Sending message", { data });
        if (!this.ws) {
            throw new Error("WebSocket is not initialized");
        }
        this.ws.send(data);
    }
    handleOpen() {
        (0, log_1.log)("Connected to WebSocket", {
            url: this.url,
            route: this.route,
        });
    }
    handlePing(data) {
        (0, log_1.log)("Received Ping", { data });
    }
    handlePong(data) {
        (0, log_1.log)("Received Pong", { data });
    }
    handleMessage(data) {
        (0, log_1.log)("Received Message", { data });
    }
    handleError(error) {
        (0, log_1.log)("WebSocket error", { error });
    }
}
exports.WebsocketProxy = WebsocketProxy;
